pub struct Script { /* private fields */ }Expand description
A a sequence of several GraphQL queries or mutations.
It can be parsed from a string, then optionally enriched with variables and executed.
Queries and mutations starting with _ are not returned in the final list
of responses. This is useful for ommiting the feedback from the initial
“populate the DB” boilerplate in the response snapshot.
Implementations